@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -139,7 +139,7 @@ namespace
     class OTablePreviewWindow : public Window
     {
         DECL_LINK(OnDisableInput, void*);
-        void ImplInitSettings( BOOL bFont, BOOL bForeground, BOOL bBackground );
+        void ImplInitSettings( sal_Bool bFont, sal_Bool bForeground, sal_Bool bBackground );
     protected:
         virtual void DataChanged(const DataChangedEvent& rDCEvt);
     public:
@@ -162,7 +162,7 @@ namespace
     // -----------------------------------------------------------------------------
     IMPL_LINK(OTablePreviewWindow, OnDisableInput, void*, EMPTYARG)
     {
-        EnableInput(FALSE);
+        EnableInput(sal_False);
         return 0L;
     }
     // -----------------------------------------------------------------------------
@@ -193,7 +193,7 @@ namespace
         {
             SetTextColor( rStyleSettings.GetFieldTextColor() );
             SetTextFillColor();
-        } // if( bForeground || bFont )
+        }
 
         if( bBackground )
             SetBackground( rStyleSettings.GetFieldColor() );
@@ -225,7 +225,7 @@ OAppDetailPageHelper::OAppDetailPageHelper(Window* _pParent,OAppBorderWindow& _r
     m_aTBPreview.SetHelpId(HID_APP_VIEW_PREVIEW_CB);
     m_aTBPreview.SetDropdownClickHdl( LINK( this, OAppDetailPageHelper, OnDropdownClickHdl ) );
     m_aTBPreview.EnableMenuStrings();
-    m_aTBPreview.Enable(TRUE);
+    m_aTBPreview.Enable(sal_True);
 
     m_aBorder.SetUniqueId(UID_APP_VIEW_PREVIEW_1);
 
@@ -254,7 +254,7 @@ OAppDetailPageHelper::~OAppDetailPageHelper()
     }
     catch(Exception)
     {
-        OSL_ENSURE(0,"Exception thrown while disposing preview frame!");
+        OSL_FAIL("Exception thrown while disposing preview frame!");
     }
 
     for (int i=0; i < E_ELEMENT_TYPE_COUNT; ++i)
@@ -289,7 +289,7 @@ void OAppDetailPageHelper::selectAll()
     int nPos = getVisibleControlIndex();
     if ( nPos < E_ELEMENT_TYPE_COUNT )
     {
-        m_pLists[nPos]->SelectAll(TRUE);
+        m_pLists[nPos]->SelectAll(sal_True);
     }
 }
 // -----------------------------------------------------------------------------
@@ -374,7 +374,7 @@ void OAppDetailPageHelper::describeCurrentSelectionForControl( const Control& _r
             return;
         }
     }
-    OSL_ENSURE( false, "OAppDetailPageHelper::describeCurrentSelectionForControl: invalid control!" );
+    OSL_FAIL( "OAppDetailPageHelper::describeCurrentSelectionForControl: invalid control!" );
 }
 
 // -----------------------------------------------------------------------------
@@ -430,7 +430,7 @@ void OAppDetailPageHelper::describeCurrentSelectionForType( const ElementType _e
         }
         break;
         default:
-            OSL_ENSURE( false, "OAppDetailPageHelper::describeCurrentSelectionForType: unexpected type!" );
+            OSL_FAIL( "OAppDetailPageHelper::describeCurrentSelectionForType: unexpected type!" );
             break;
         }
 
@@ -453,7 +453,7 @@ void OAppDetailPageHelper::selectElements(const Sequence< ::rtl::OUString>& _aNa
     if ( nPos < E_ELEMENT_TYPE_COUNT )
     {
         DBTreeListBox& rTree = *m_pLists[nPos];
-        rTree.SelectAll(FALSE);
+        rTree.SelectAll(sal_False);
         const ::rtl::OUString* pIter = _aNames.getConstArray();
         const ::rtl::OUString* pEnd  = pIter + _aNames.getLength();
         for(;pIter != pEnd;++pIter)
@@ -543,13 +543,11 @@ sal_Bool OAppDetailPageHelper::isCutAllowed()
 // -----------------------------------------------------------------------------
 sal_Bool OAppDetailPageHelper::isCopyAllowed()
 {
-    //int nPos = getVisibleControlIndex();
     return sal_True;
 }
 // -----------------------------------------------------------------------------
 sal_Bool OAppDetailPageHelper::isPasteAllowed()
 {
-    //int nPos = getVisibleControlIndex();
     return sal_True;
 }
 // -----------------------------------------------------------------------------
@@ -604,7 +602,7 @@ SvLBoxEntry* OAppDetailPageHelper::getEntry( const Point& _aPosPixel) const
     SvLBoxEntry* pReturn = NULL;
     int nPos = getVisibleControlIndex();
     if ( nPos < E_ELEMENT_TYPE_COUNT )
-        pReturn = m_pLists[nPos]->GetEntry( _aPosPixel,TRUE );
+        pReturn = m_pLists[nPos]->GetEntry( _aPosPixel,sal_True );
     return pReturn;
 }
 // -----------------------------------------------------------------------------
@@ -623,8 +621,7 @@ void OAppDetailPageHelper::createTablesPage(const Reference< XConnection>& _xCon
 
         ImageProvider aImageProvider( _xConnection );
         createTree( pTreeView,
-            aImageProvider.getDefaultImage( DatabaseObject::TABLE, false ),
-            aImageProvider.getDefaultImage( DatabaseObject::TABLE, true )
+            aImageProvider.getDefaultImage( DatabaseObject::TABLE )
         );
 
         pTreeView->notifyHiContrastChanged();
@@ -637,17 +634,17 @@ void OAppDetailPageHelper::createTablesPage(const Reference< XConnection>& _xCon
         SvLBoxEntry* pEntry = m_pLists[E_TABLE]->First();
         if ( pEntry )
             m_pLists[E_TABLE]->Expand(pEntry);
-        m_pLists[E_TABLE]->SelectAll(FALSE);
+        m_pLists[E_TABLE]->SelectAll(sal_False);
     }
 
     setDetailPage(m_pLists[E_TABLE]);
 }
 
 // -----------------------------------------------------------------------------
-void OAppDetailPageHelper::getElementIcons( ElementType _eType, USHORT& _rImageId, USHORT& _rHighContrastImageId )
+void OAppDetailPageHelper::getElementIcons( ElementType _eType, sal_uInt16& _rImageId)
 {
     ImageProvider aImageProvider;
-    _rImageId = _rHighContrastImageId = 0;
+    _rImageId = 0;
 
     sal_Int32 nDatabaseObjectType( 0 );
     switch(_eType )
@@ -656,11 +653,10 @@ void OAppDetailPageHelper::getElementIcons( ElementType _eType, USHORT& _rImageI
         case E_REPORT:  nDatabaseObjectType = DatabaseObject::REPORT; break;
         case E_QUERY:   nDatabaseObjectType = DatabaseObject::QUERY; break;
         default:
-            OSL_ENSURE( sal_False, "OAppDetailPageHelper::GetElementIcons: invalid element type!" );
+            OSL_FAIL( "OAppDetailPageHelper::GetElementIcons: invalid element type!" );
             return;
     }
-    _rImageId = aImageProvider.getDefaultImageResourceID( nDatabaseObjectType, false );
-    _rHighContrastImageId = aImageProvider.getDefaultImageResourceID( nDatabaseObjectType, true );
+    _rImageId = aImageProvider.getDefaultImageResourceID( nDatabaseObjectType );
 }
 
 // -----------------------------------------------------------------------------
@@ -668,43 +664,41 @@ void OAppDetailPageHelper::createPage(ElementType _eType,const Reference< XNameA
 {
     OSL_ENSURE(E_TABLE != _eType,"E_TABLE isn't allowed.");
 
-    USHORT nHelpId = 0, nImageId = 0, nImageIdH = 0;
+    sal_uInt16 nImageId = 0;
+    rtl::OString sHelpId;
     ImageProvider aImageProvider;
-    Image aFolderImage, aFolderImageHC;
+    Image aFolderImage;
     switch( _eType )
     {
         case E_FORM:
-            nHelpId = HID_APP_FORM_TREE;
-            aFolderImage = aImageProvider.getFolderImage( DatabaseObject::FORM, false );
-            aFolderImageHC = aImageProvider.getFolderImage( DatabaseObject::FORM, true );
+            sHelpId = HID_APP_FORM_TREE;
+            aFolderImage = aImageProvider.getFolderImage( DatabaseObject::FORM );
             break;
         case E_REPORT:
-            nHelpId = HID_APP_REPORT_TREE;
-            aFolderImage = aImageProvider.getFolderImage( DatabaseObject::REPORT, false );
-            aFolderImageHC = aImageProvider.getFolderImage( DatabaseObject::REPORT, true );
+            sHelpId = HID_APP_REPORT_TREE;
+            aFolderImage = aImageProvider.getFolderImage( DatabaseObject::REPORT );
             break;
         case E_QUERY:
-            nHelpId = HID_APP_QUERY_TREE;
-            aFolderImage = aImageProvider.getFolderImage( DatabaseObject::QUERY, false );
-            aFolderImageHC = aImageProvider.getFolderImage( DatabaseObject::QUERY, true );
+            sHelpId = HID_APP_QUERY_TREE;
+            aFolderImage = aImageProvider.getFolderImage( DatabaseObject::QUERY );
             break;
         default:
-            OSL_ENSURE(0,"Illegal call!");
+            OSL_FAIL("Illegal call!");
     }
-    getElementIcons( _eType, nImageId, nImageIdH );
+    getElementIcons( _eType, nImageId );
 
     if ( !m_pLists[_eType] )
     {
-        m_pLists[_eType] = createSimpleTree( nHelpId, aFolderImage, aFolderImageHC );
+        m_pLists[_eType] = createSimpleTree( sHelpId, aFolderImage );
     }
 
     if ( m_pLists[_eType] )
     {
         if ( !m_pLists[_eType]->GetEntryCount() && _xContainer.is() )
         {
-            fillNames( _xContainer, _eType, nImageId, nImageIdH, NULL );
+            fillNames( _xContainer, _eType, nImageId, NULL );
 
-            m_pLists[_eType]->SelectAll(FALSE);
+            m_pLists[_eType]->SelectAll(sal_False);
         }
         setDetailPage(m_pLists[_eType]);
     }
@@ -718,7 +712,7 @@ void OAppDetailPageHelper::setDetailPage(Window* _pWindow)
         pCurrent->Hide();
 
     showPreview(NULL);
-    BOOL bHasFocus = FALSE;
+    sal_Bool bHasFocus = sal_False;
     m_aFL.Show();
     {
         bHasFocus = pCurrent->HasChildPathFocus();
@@ -726,7 +720,7 @@ void OAppDetailPageHelper::setDetailPage(Window* _pWindow)
     }
     m_aTBPreview.Show();
     m_aBorder.Show();
-    switchPreview(m_ePreviewMode,TRUE);
+    switchPreview(m_ePreviewMode,sal_True);
 
     if ( bHasFocus )
         _pWindow->GrabFocus();
@@ -750,7 +744,7 @@ namespace
 
 // -----------------------------------------------------------------------------
 void OAppDetailPageHelper::fillNames( const Reference< XNameAccess >& _xContainer, const ElementType _eType,
-                                      const USHORT _nImageId, const USHORT _nHighContrastImageId, SvLBoxEntry* _pParent )
+                                      const sal_uInt16 _nImageId, SvLBoxEntry* _pParent )
 {
     OSL_ENSURE(_xContainer.is(),"Data source is NULL! -> GPF");
     OSL_ENSURE( ( _eType >= E_TABLE ) && ( _eType < E_ELEMENT_TYPE_COUNT ), "OAppDetailPageHelper::fillNames: invalid type!" );
@@ -773,47 +767,41 @@ void OAppDetailPageHelper::fillNames( const Reference< XNameAccess >& _xContaine
             Reference<XNameAccess> xSubElements(_xContainer->getByName(*pIter),UNO_QUERY);
             if ( xSubElements.is() )
             {
-                pEntry = pList->InsertEntry( *pIter, _pParent, FALSE, LIST_APPEND, reinterpret_cast< void* >( nFolderIndicator ) );
+                pEntry = pList->InsertEntry( *pIter, _pParent, sal_False, LIST_APPEND, reinterpret_cast< void* >( nFolderIndicator ) );
                 getBorderWin().getView()->getAppController().containerFound( Reference< XContainer >( xSubElements, UNO_QUERY ) );
-                fillNames( xSubElements, _eType, _nImageId, _nHighContrastImageId, pEntry );
+                fillNames( xSubElements, _eType, _nImageId, pEntry );
             }
             else
             {
                 pEntry = pList->InsertEntry( *pIter, _pParent );
 
                 Image aImage = Image( ModuleRes( _nImageId ) );
-                pList->SetExpandedEntryBmp( pEntry, aImage, BMP_COLOR_NORMAL );
-                pList->SetCollapsedEntryBmp( pEntry, aImage, BMP_COLOR_NORMAL );
-
-                Image aHCImage = Image( ModuleRes( _nHighContrastImageId ) );
-                pList->SetExpandedEntryBmp( pEntry, aHCImage, BMP_COLOR_HIGHCONTRAST );
-                pList->SetCollapsedEntryBmp( pEntry, aHCImage, BMP_COLOR_HIGHCONTRAST );
+                pList->SetExpandedEntryBmp(  pEntry, aImage );
+                pList->SetCollapsedEntryBmp( pEntry, aImage );
             }
         }
     }
 }
 // -----------------------------------------------------------------------------
-DBTreeListBox* OAppDetailPageHelper::createSimpleTree( ULONG _nHelpId, const Image& _rImage, const Image& _rImageHC )
+DBTreeListBox* OAppDetailPageHelper::createSimpleTree( const rtl::OString& _sHelpId, const Image& _rImage)
 {
     DBTreeListBox* pTreeView = new DBTreeListBox(this,getBorderWin().getView()->getORB(),WB_HASLINES | WB_SORT | WB_HASBUTTONS | WB_HSCROLL |WB_HASBUTTONSATROOT | WB_TABSTOP);
-    pTreeView->SetHelpId(_nHelpId);
-    return createTree( pTreeView, _rImage, _rImageHC );
+    pTreeView->SetHelpId( _sHelpId );
+    return createTree( pTreeView, _rImage );
 }
 
 // -----------------------------------------------------------------------------
-DBTreeListBox* OAppDetailPageHelper::createTree( DBTreeListBox* _pTreeView, const Image& _rImage, const Image& _rImageHC )
+DBTreeListBox* OAppDetailPageHelper::createTree( DBTreeListBox* _pTreeView, const Image& _rImage )
 {
     WaitObject aWaitCursor(this);
 
-    _pTreeView->SetWindowBits(WB_HASLINES | WB_SORT | WB_HASBUTTONS | WB_HSCROLL |WB_HASBUTTONSATROOT | WB_TABSTOP);
+    _pTreeView->SetStyle(_pTreeView->GetStyle() | WB_HASLINES | WB_SORT | WB_HASBUTTONS | WB_HSCROLL |WB_HASBUTTONSATROOT | WB_TABSTOP);
     _pTreeView->GetModel()->SetSortMode(SortAscending);
     _pTreeView->EnableCheckButton( NULL ); // do not show any buttons
     _pTreeView->SetSelectionMode(MULTIPLE_SELECTION);
 
     _pTreeView->SetDefaultCollapsedEntryBmp( _rImage );
-    _pTreeView->SetDefaultCollapsedEntryBmp( _rImageHC, BMP_COLOR_HIGHCONTRAST );
     _pTreeView->SetDefaultExpandedEntryBmp( _rImage );
-    _pTreeView->SetDefaultExpandedEntryBmp( _rImageHC, BMP_COLOR_HIGHCONTRAST );
 
     _pTreeView->SetDoubleClickHdl(LINK(this, OAppDetailPageHelper, OnEntryDoubleClick));
     _pTreeView->SetEnterKeyHdl(LINK(this, OAppDetailPageHelper, OnEntryDoubleClick));
@@ -872,7 +860,7 @@ void OAppDetailPageHelper::elementReplaced(ElementType _eType
                 pEntry = lcl_findEntry(*pTreeView,_rOldName,pTreeView->First());
                 break;
             default:
-                OSL_ENSURE(0,"Invalid element type");
+                OSL_FAIL("Invalid element type");
         }
         OSL_ENSURE(pEntry,"Do you know that the name isn't existence!");
         if ( pEntry )
@@ -905,26 +893,22 @@ SvLBoxEntry* OAppDetailPageHelper::elementAdded(ElementType _eType,const ::rtl::
             }
         }
 
-        USHORT nImageId = 0, nImageIdH = 0;
-        getElementIcons( _eType, nImageId, nImageIdH );
+        sal_uInt16 nImageId = 0;
+        getElementIcons( _eType, nImageId );
         Reference<XNameAccess> xContainer(_rObject,UNO_QUERY);
         if ( xContainer.is() )
         {
             const sal_Int32 nFolderIndicator = lcl_getFolderIndicatorForType( _eType );
-            pRet = pTreeView->InsertEntry( _rName, pEntry, FALSE, LIST_APPEND, reinterpret_cast< void* >( nFolderIndicator ) );
-            fillNames( xContainer, _eType, nImageId, nImageIdH, pRet );
+            pRet = pTreeView->InsertEntry( _rName, pEntry, sal_False, LIST_APPEND, reinterpret_cast< void* >( nFolderIndicator ) );
+            fillNames( xContainer, _eType, nImageId, pRet );
         }
         else
         {
             pRet = pTreeView->InsertEntry( _rName, pEntry );
 
             Image aImage = Image( ModuleRes( nImageId ) );
-            pTreeView->SetExpandedEntryBmp( pRet, aImage, BMP_COLOR_NORMAL );
-            pTreeView->SetCollapsedEntryBmp( pRet, aImage, BMP_COLOR_NORMAL );
-
-            Image aHCImage = Image( ModuleRes( nImageIdH ) );
-            pTreeView->SetExpandedEntryBmp( pRet, aHCImage, BMP_COLOR_HIGHCONTRAST );
-            pTreeView->SetCollapsedEntryBmp( pRet, aHCImage, BMP_COLOR_HIGHCONTRAST );
+            pTreeView->SetExpandedEntryBmp(  pRet, aImage );
+            pTreeView->SetCollapsedEntryBmp( pRet, aImage );
         }
     }
     return pRet;
@@ -961,7 +945,7 @@ void OAppDetailPageHelper::elementRemoved( ElementType _eType,const ::rtl::OUStr
                 }
                 break;
             default:
-                OSL_ENSURE(0,"Invalid element type");
+                OSL_FAIL("Invalid element type");
         }
         if ( !pTreeView->GetEntryCount() )
             showPreview(NULL);
@@ -1007,8 +991,7 @@ IMPL_LINK( OAppDetailPageHelper, OnDeleteEntry, void*, /*NOINTERESTEDIN*/ )
 // -----------------------------------------------------------------------------
 void OAppDetailPageHelper::Resize()
 {
-    //////////////////////////////////////////////////////////////////////
-    // Abmessungen parent window
+    // parent window dimension
     Size aOutputSize( GetOutputSize() );
     long nOutputWidth  = aOutputSize.Width();
     long nOutputHeight = aOutputSize.Height();
@@ -1047,7 +1030,7 @@ sal_Bool OAppDetailPageHelper::isPreviewEnabled()
     return m_ePreviewMode != E_PREVIEWNONE;
 }
 // -----------------------------------------------------------------------------
-void OAppDetailPageHelper::switchPreview(PreviewMode _eMode,BOOL _bForce)
+void OAppDetailPageHelper::switchPreview(PreviewMode _eMode,sal_Bool _bForce)
 {
     if ( m_ePreviewMode != _eMode || _bForce )
     {
@@ -1145,12 +1128,6 @@ void OAppDetailPageHelper::showPreview(const Reference< XContent >& _xContent)
             {
                 m_aPreview.Hide();
                 m_aDocumentInfo.Hide();
-
-                // Why the below code? It might have side effects, as the tree view needs to know
-                // its current selection for other purposes than the preview, too.
-//                DBTreeListBox* pTreeView = getCurrentView();
-//                if ( pTreeView )
-//                    pTreeView->clearCurrentSelection();
             }
         }
         catch( const Exception& )
@@ -1177,9 +1154,9 @@ void OAppDetailPageHelper::showPreview( const ::rtl::OUString& _sDataSourceName,
                 m_xFrame = Reference < XFrame > ( getBorderWin().getView()->getORB()->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.Frame")) ), UNO_QUERY );
                 m_xFrame->initialize( m_xWindow );
 
-                // work-around for #150518#: no layout manager (and thus no toolbars) in the preview
+                // no layout manager (and thus no toolbars) in the preview
                 // Must be called after initialize ... but before any other call to this frame.
-                // Otherwhise frame throws "life time exceptions" as e.g. NON_INITIALIZED
+                // Otherwise frame throws "life time exceptions" as e.g. NON_INITIALIZED
                 Reference< XPropertySet > xFrameProps( m_xFrame, UNO_QUERY_THROW );
                 xFrameProps->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "LayoutManager" ) ), makeAny(Reference< XLayoutManager >()) );
 
@@ -1278,7 +1255,7 @@ void OAppDetailPageHelper::KeyInput( const KeyEvent& rKEvt )
     OSL_PRECOND( pCurrentView, "OAppDetailPageHelper::KeyInput: how this?" );
 
     KeyFuncType eFunc = rKEvt.GetKeyCode().GetFunction(); (void)eFunc;
-    USHORT      nCode = rKEvt.GetKeyCode().GetCode();
+    sal_uInt16      nCode = rKEvt.GetKeyCode().GetCode();
 
     if ( ( KEY_RETURN == nCode ) && pCurrentView )
     {
@@ -1314,34 +1291,25 @@ void OAppDetailPageHelper::DataChanged( const DataChangedEvent& rDCEvt )
 void OAppDetailPageHelper::ImplInitSettings()
 {
     const StyleSettings& rStyleSettings = GetSettings().GetStyleSettings();
-    if( true )
-    {
         Font aFont;
         aFont = rStyleSettings.GetFieldFont();
         aFont.SetColor( rStyleSettings.GetWindowTextColor() );
         SetPointFont( aFont );
         m_aTBPreview.SetPointFont( aFont );
-    }
 
-    if( true )
-    {
         SetTextColor( rStyleSettings.GetFieldTextColor() );
         SetTextFillColor();
         m_aBorder.SetTextColor( rStyleSettings.GetFieldTextColor() );
         m_aBorder.SetTextFillColor();
         m_aTBPreview.SetTextColor( rStyleSettings.GetFieldTextColor() );
         m_aTBPreview.SetTextFillColor();
-    } // if( true )
 
-    if( true )
-    {
         SetBackground( rStyleSettings.GetFieldColor() );
         m_aBorder.SetBackground( rStyleSettings.GetFieldColor() );
         m_aFL.SetBackground( rStyleSettings.GetFieldColor() );
         m_aDocumentInfo.SetBackground( rStyleSettings.GetFieldColor() );
         m_aTBPreview.SetBackground( rStyleSettings.GetFieldColor() );
         m_pTablePreview->SetBackground( rStyleSettings.GetFieldColor() );
-    } // if( true )
 }
 // -----------------------------------------------------------------------------
 OPreviewWindow::OPreviewWindow(Window* _pParent)
@@ -1350,11 +1318,11 @@ OPreviewWindow::OPreviewWindow(Window* _pParent)
     ImplInitSettings( sal_True, sal_True, sal_True );
 }
 // -----------------------------------------------------------------------------
-BOOL OPreviewWindow::ImplGetGraphicCenterRect( const Graphic& rGraphic, Rectangle& rResultRect ) const
+sal_Bool OPreviewWindow::ImplGetGraphicCenterRect( const Graphic& rGraphic, Rectangle& rResultRect ) const
 {
     const Size aWinSize( GetOutputSizePixel() );
     Size       aNewSize( LogicToPixel( rGraphic.GetPrefSize(), rGraphic.GetPrefMapMode() ) );
-    BOOL       bRet = FALSE;
+    sal_Bool       bRet = sal_False;
 
     if( aNewSize.Width() && aNewSize.Height() )
     {
@@ -1377,7 +1345,7 @@ BOOL OPreviewWindow::ImplGetGraphicCenterRect( const Graphic& rGraphic, Rectangl
                              ( aWinSize.Height() - aNewSize.Height() ) >> 1 );
 
         rResultRect = Rectangle( aNewPos, aNewSize );
-        bRet = TRUE;
+        bRet = sal_True;
     }
 
     return bRet;
@@ -1428,7 +1396,7 @@ void OPreviewWindow::ImplInitSettings( sal_Bool bFont, sal_Bool bForeground, sal
     {
         SetTextColor( rStyleSettings.GetFieldTextColor() );
         SetTextFillColor();
-    } // if( bForeground || bFont )
+    }
 
     if( bBackground )
         SetBackground( rStyleSettings.GetFieldColor() );
