@@ -33,7 +33,6 @@
 
 #include <svtools/editbrowsebox.hxx>
 #include <com/sun/star/beans/XPropertySet.hpp>
-#include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
 #include "TableConnectionData.hxx"
 #include "TableConnection.hxx"
@@ -45,7 +44,7 @@
 #include "RelControliFace.hxx"
 #include "dbu_control.hrc"
 #include "dbaccess_helpid.hrc"
-#include <tools/debug.hxx>
+#include <osl/diagnose.h>
 
 #include <algorithm>
 
@@ -75,14 +74,14 @@ namespace dbaui
         Reference< XPropertySet>				m_xDestDef;
 
 
-        void fillListBox(const Reference< XPropertySet>& _xDest,long nRow,USHORT nColumnId);
+        void fillListBox(const Reference< XPropertySet>& _xDest,long nRow,sal_uInt16 nColumnId);
         /** returns the column id for the editbrowsebox
             @param	_nColId
                     the column id SOURCE_COLUMN or DEST_COLUMN
 
             @return	the current column id eihter SOURCE_COLUMN or DEST_COLUMN depends on the connection data
         */
-        USHORT getColumnIdent( USHORT _nColId ) const;
+        sal_uInt16 getColumnIdent( sal_uInt16 _nColId ) const;
     public:
         ORelationControl( OTableListBoxControl* pParent,const OJoinTableView::OTableWindowMap* _pTableMap );
         virtual ~ORelationControl();
@@ -108,16 +107,16 @@ namespace dbaui
 
         virtual long PreNotify(NotifyEvent& rNEvt );
 
-        virtual BOOL IsTabAllowed(BOOL bForward) const;
+        virtual sal_Bool IsTabAllowed(sal_Bool bForward) const;
 
         virtual void Init(const TTableConnectionData::value_type& _pConnData);
         virtual void Init() { ORelationControl_Base::Init(); }
-        virtual void InitController( ::svt::CellControllerRef& rController, long nRow, USHORT nCol );
-        virtual ::svt::CellController* GetController( long nRow, USHORT nCol );
-        virtual void PaintCell( OutputDevice& rDev, const Rectangle& rRect, USHORT nColId ) const;
-        virtual BOOL SeekRow( long nRow );
-        virtual BOOL SaveModified();
-        virtual String GetCellText( long nRow, USHORT nColId ) const;
+        virtual void InitController( ::svt::CellControllerRef& rController, long nRow, sal_uInt16 nCol );
+        virtual ::svt::CellController* GetController( long nRow, sal_uInt16 nCol );
+        virtual void PaintCell( OutputDevice& rDev, const Rectangle& rRect, sal_uInt16 nColId ) const;
+        virtual sal_Bool SeekRow( long nRow );
+        virtual sal_Bool SaveModified();
+        virtual String GetCellText( long nRow, sal_uInt16 nColId ) const;
 
         virtual void CellModified();
 
@@ -134,7 +133,7 @@ namespace dbaui
     DBG_NAME(ORelationControl)
     //------------------------------------------------------------------------
     ORelationControl::ORelationControl( OTableListBoxControl* pParent ,const OJoinTableView::OTableWindowMap* _pTableMap)
-        :EditBrowseBox( pParent, EBBF_SMART_TAB_TRAVEL | EBBF_NOROWPICTURE, WB_TABSTOP | /*WB_3DLOOK | */WB_BORDER | BROWSER_AUTOSIZE_LASTCOL)
+        :EditBrowseBox( pParent, EBBF_SMART_TAB_TRAVEL | EBBF_NOROWPICTURE, WB_TABSTOP | WB_BORDER | BROWSER_AUTOSIZE_LASTCOL)
         ,m_pTableMap(_pTableMap)
         ,m_pBoxControl(pParent)
         ,m_xSourceDef( NULL )
@@ -189,7 +188,7 @@ namespace dbaui
             // not the first call
             RowRemoved(0, GetRowCount());
 
-        RowInserted(0, m_pConnData->GetConnLineDataList()->size() + 1, TRUE); // add one extra row
+        RowInserted(0, m_pConnData->GetConnLineDataList()->size() + 1, sal_True); // add one extra row
     }
     //------------------------------------------------------------------------------
     void ORelationControl::Resize()
@@ -228,20 +227,20 @@ namespace dbaui
     }
 
     //------------------------------------------------------------------------------
-    BOOL ORelationControl::IsTabAllowed(BOOL bForward) const
+    sal_Bool ORelationControl::IsTabAllowed(sal_Bool bForward) const
     {
         DBG_CHKTHIS(ORelationControl,NULL);
         long nRow = GetCurRow();
-        USHORT nCol = GetCurColumnId();
+        sal_uInt16 nCol = GetCurColumnId();
 
-        BOOL bRet = !((		( bForward && (nCol == DEST_COLUMN)		&& (nRow == GetRowCount() - 1))) 
+        sal_Bool bRet = !((		( bForward && (nCol == DEST_COLUMN)		&& (nRow == GetRowCount() - 1))) 
                         ||	(!bForward && (nCol == SOURCE_COLUMN)	&& (nRow == 0)));
 
         return bRet && EditBrowseBox::IsTabAllowed(bForward);
     }
 
     //------------------------------------------------------------------------------
-    BOOL ORelationControl::SaveModified()
+    sal_Bool ORelationControl::SaveModified()
     {
         DBG_CHKTHIS(ORelationControl,NULL);
         sal_Int32 nRow = GetCurRow();
@@ -268,19 +267,19 @@ namespace dbaui
             }
         }
 
-        return TRUE;
+        return sal_True;
     }
     //------------------------------------------------------------------------------
-    USHORT ORelationControl::getColumnIdent( USHORT _nColId ) const
+    sal_uInt16 ORelationControl::getColumnIdent( sal_uInt16 _nColId ) const
     {
-        USHORT nId = _nColId;
+        sal_uInt16 nId = _nColId;
         if ( m_pConnData->getReferencingTable() != m_pBoxControl->getReferencingTable() )
             nId = ( _nColId == SOURCE_COLUMN) ? DEST_COLUMN : SOURCE_COLUMN;
         return nId;
     }
 
     //------------------------------------------------------------------------------
-    String ORelationControl::GetCellText( long nRow, USHORT nColId ) const
+    String ORelationControl::GetCellText( long nRow, sal_uInt16 nColId ) const
     {
         DBG_CHKTHIS(ORelationControl,NULL);
         String sText;
@@ -301,22 +300,22 @@ namespace dbaui
     }
 
     //------------------------------------------------------------------------------
-    void ORelationControl::InitController( CellControllerRef& /*rController*/, long nRow, USHORT nColumnId )
+    void ORelationControl::InitController( CellControllerRef& /*rController*/, long nRow, sal_uInt16 nColumnId )
     {
         DBG_CHKTHIS(ORelationControl,NULL);
         
-        ULONG nHelpId = HID_RELATIONDIALOG_LEFTFIELDCELL;
+        rtl::OString sHelpId( HID_RELATIONDIALOG_LEFTFIELDCELL );
 
         Reference< XPropertySet> xDef;
         switch ( getColumnIdent(nColumnId) )
         {
             case SOURCE_COLUMN:
                 xDef	= m_xSourceDef;
-                nHelpId = HID_RELATIONDIALOG_LEFTFIELDCELL;
+                sHelpId = HID_RELATIONDIALOG_LEFTFIELDCELL;
                 break;
             case DEST_COLUMN:
                 xDef	= m_xDestDef;
-                nHelpId = HID_RELATIONDIALOG_RIGHTFIELDCELL;
+                sHelpId = HID_RELATIONDIALOG_RIGHTFIELDCELL;
                 break;
             default:
                 //  ?????????
@@ -334,27 +333,27 @@ namespace dbaui
                 m_pListCell->SelectEntry( sName );
             }
 
-            m_pListCell->SetHelpId(nHelpId);
+            m_pListCell->SetHelpId(sHelpId);
         }
     }
 
     //------------------------------------------------------------------------------
-    CellController* ORelationControl::GetController( long /*nRow*/, USHORT /*nColumnId*/ )
+    CellController* ORelationControl::GetController( long /*nRow*/, sal_uInt16 /*nColumnId*/ )
     {
         DBG_CHKTHIS(ORelationControl,NULL);
         return new ListBoxCellController( m_pListCell.get() );
     }
 
     //------------------------------------------------------------------------------
-    BOOL ORelationControl::SeekRow( long nRow )
+    sal_Bool ORelationControl::SeekRow( long nRow )
     {
         DBG_CHKTHIS(ORelationControl,NULL);
         m_nDataPos = nRow;
-        return TRUE;
+        return sal_True;
     }
 
     //------------------------------------------------------------------------------
-    void ORelationControl::PaintCell( OutputDevice& rDev, const Rectangle& rRect, USHORT nColumnId ) const
+    void ORelationControl::PaintCell( OutputDevice& rDev, const Rectangle& rRect, sal_uInt16 nColumnId ) const
     {
         DBG_CHKTHIS(ORelationControl,NULL);
         String aText  =const_cast< ORelationControl*>(this)->GetCellText( m_nDataPos, nColumnId );
@@ -372,7 +371,7 @@ namespace dbaui
             rDev.SetClipRegion();
     }
     // -----------------------------------------------------------------------------
-    void ORelationControl::fillListBox(const Reference< XPropertySet>& _xDest,long /*_nRow*/,USHORT /*nColumnId*/)
+    void ORelationControl::fillListBox(const Reference< XPropertySet>& _xDest,long /*_nRow*/,sal_uInt16 /*nColumnId*/)
     {
         m_pListCell->Clear();
         try
@@ -401,7 +400,7 @@ namespace dbaui
     void ORelationControl::setWindowTables(const OTableWindow* _pSource,const OTableWindow* _pDest)
     {
         // wenn ich hier gerade editiere, ausblenden
-        BOOL bWasEditing = IsEditing();
+        sal_Bool bWasEditing = IsEditing();
         if ( bWasEditing )
             DeactivateCell();
 
@@ -496,7 +495,7 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
     // -----------------------------------------------------------------------------
     void OTableListBoxControl::fillListBoxes()
     {
-        DBG_ASSERT( !m_pTableMap->empty(), "OTableListBoxControl::fillListBoxes: no table window!");
+        OSL_ENSURE( !m_pTableMap->empty(), "OTableListBoxControl::fillListBoxes: no table window!");
         OTableWindow* pInitialLeft = NULL;
         OTableWindow* pInitialRight = NULL;
 
@@ -518,7 +517,7 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
                 pInitialRight = aIter->second;
                 m_strCurrentRight = aIter->first;
             }
-        } // for(;aIter != m_pTableMap->end();++aIter)
+        }
 
         if ( !pInitialRight )
         {
@@ -583,7 +582,7 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
             OTableWindow* pLoop = NULL;
             if( aFind != m_pTableMap->end() )
                 pLoop = aFind->second;
-            DBG_ASSERT(pLoop != NULL, "ORelationDialog::OnTableChanged : ungueltiger Eintrag in ListBox !");
+            OSL_ENSURE(pLoop != NULL, "ORelationDialog::OnTableChanged : ungueltiger Eintrag in ListBox !");
                 // da ich die ListBoxen selber mit eben diesen Tabellennamen, mit denen ich sie jetzt vergleiche, gefuellt habe,
                 // MUSS ich strSelected finden
             if (pListBox == &m_lmbLeftTable)
@@ -637,7 +636,7 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
         if ( pLines->size() >= static_cast<sal_uInt32>(m_pRC_Tables->GetRowCount()) )
         {
             m_pRC_Tables->DeactivateCell();
-            m_pRC_Tables->RowInserted(m_pRC_Tables->GetRowCount(), pLines->size() - static_cast<sal_uInt32>(m_pRC_Tables->GetRowCount()) + 1, TRUE);
+            m_pRC_Tables->RowInserted(m_pRC_Tables->GetRowCount(), pLines->size() - static_cast<sal_uInt32>(m_pRC_Tables->GetRowCount()) + 1, sal_True);
             m_pRC_Tables->ActivateCell();
         }
     }
@@ -668,7 +667,6 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
         {
             _pTableSeparator->SetZOrder(&m_lmbRightTable, WINDOW_ZORDER_BEHIND);
             m_pRC_Tables->SetZOrder(_pTableSeparator, WINDOW_ZORDER_BEHIND);
-            //aDlgPoint = m_pTableSeparator->GetPosPixel() + Point(0,aSize.Height()) + LogicToPixel( Point(0,6), MAP_APPFONT );
             _pTableSeparator->SetPosPixel(Point(0,m_aFL_InvolvedFields.GetPosPixel().Y()));
             const Size aSize = _pTableSeparator->GetSizePixel();
             aDlgPoint.Y() = _pTableSeparator->GetPosPixel().Y() + aSize.Height();
@@ -693,9 +691,9 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
         m_pRC_Tables->lateInit();
     }
     // -----------------------------------------------------------------------------
-    BOOL OTableListBoxControl::SaveModified()
+    sal_Bool OTableListBoxControl::SaveModified()
     {
-        BOOL bRet = m_pRC_Tables->SaveModified();
+        sal_Bool bRet = m_pRC_Tables->SaveModified();
         m_pRC_Tables->getData()->normalizeLines();
         return bRet;
     }
