@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -28,56 +29,24 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_dbaccess.hxx"
 
-#ifndef DBAUI_DBTREELISTBOX_HXX
 #include "dbtreelistbox.hxx"
-#endif
-#ifndef _DBU_RESOURCE_HRC_
 #include "dbu_resource.hrc"
-#endif
-#ifndef DBACCESS_UI_BROWSER_ID_HXX
 #include "browserids.hxx"
-#endif
-#ifndef _DBAUI_LISTVIEWITEMS_HXX_
 #include "listviewitems.hxx"
-#endif
-#ifndef _DBACCESS_UI_CALLBACKS_HXX_
 #include "callbacks.hxx"
-#endif
 
-#ifndef _COM_SUN_STAR_DATATRANSFER_DND_XDRAGGESTURELISTENER_HDL_
 #include <com/sun/star/datatransfer/dnd/XDragGestureListener.hdl>
-#endif
-#ifndef _COM_SUN_STAR_DATATRANSFER_DND_XDRAGGESTURERECOGNIZER_HPP_ 
 #include <com/sun/star/datatransfer/dnd/XDragGestureRecognizer.hpp>
-#endif
-#ifndef _COM_SUN_STAR_UI_XCONTEXTMENUINTERCEPTOR_HPP_
 #include <com/sun/star/ui/XContextMenuInterceptor.hpp>
-#endif
 #include <com/sun/star/frame/XFrame.hpp>
-#ifndef _COM_SUN_STAR_UTIL_URL_HPP_
 #include <com/sun/star/util/URL.hpp>
-#endif
-#ifndef _CPPUHELPER_IMPLBASE1_HXX_
 #include <cppuhelper/implbase1.hxx>
-#endif
-#ifndef _CPPUHELPER_INTERFACECONTAINER_HXX_
 #include <cppuhelper/interfacecontainer.hxx>
-#endif
-#ifndef _SV_HELP_HXX
 #include <vcl/help.hxx>
-#endif
-#ifndef _DBAUI_TABLETREE_HRC_
 #include "tabletree.hrc"
-#endif
-#ifndef DBAUI_ICONTROLLER_HXX
 #include "IController.hxx"
-#endif
-#ifndef __FRAMEWORK_HELPER_ACTIONTRIGGERHELPER_HXX_
 #include <framework/actiontriggerhelper.hxx>
-#endif
-#ifndef _TOOLKIT_HELPER_VCLUNOHELPER_HXX_
 #include <toolkit/helper/vclunohelper.hxx>
-#endif
 #include <framework/imageproducer.hxx>
 #include <vcl/svapp.hxx>
 #include <memory>
@@ -123,12 +92,12 @@ DBTreeListBox::DBTreeListBox( Window* pParent, const Reference< XMultiServiceFac
     ,m_xORB(_rxORB)
 {
     DBG_CTOR(DBTreeListBox,NULL);
-    init();	
+    init();
 }
 // -----------------------------------------------------------------------------
 void DBTreeListBox::init()
 {
-    USHORT nSize = SPACEBETWEENENTRIES;
+    sal_uInt16 nSize = SPACEBETWEENENTRIES;
     SetSpaceBetweenEntries(nSize);
 
     m_aTimer.SetTimeout(900);
@@ -140,6 +109,8 @@ void DBTreeListBox::init()
     SetNodeDefaultImages( );
 
     EnableContextMenuHandling();
+
+    SetStyle( GetStyle() | WB_QUICK_SEARCH );
 }
 //------------------------------------------------------------------------
 DBTreeListBox::~DBTreeListBox()
@@ -155,8 +126,8 @@ SvLBoxEntry* DBTreeListBox::GetEntryPosByName( const String& aName, SvLBoxEntry*
     SvLBoxEntry* pEntry = NULL;
     if ( pChilds )
     {
-        ULONG nCount = pChilds->Count();
-        for (ULONG i=0; i < nCount; ++i)
+        sal_uLong nCount = pChilds->Count();
+        for (sal_uLong i=0; i < nCount; ++i)
         {
             pEntry = static_cast<SvLBoxEntry*>(pChilds->GetObject(i));
             SvLBoxString* pItem = (SvLBoxString*)(pEntry->GetFirstItem(SV_ITEM_ID_LBOXSTRING));
@@ -186,7 +157,7 @@ void DBTreeListBox::RequestingChilds( SvLBoxEntry* pParent )
     {
         if (!m_aPreExpandHandler.Call(pParent))
         {
-            // an error occured. The method calling us will reset the entry flags, so it can't be expanded again.
+            // an error occurred. The method calling us will reset the entry flags, so it can't be expanded again.
             // But we want that the user may do a second try (i.e. because he misstypes a password in this try), so
             // we have to reset these flags controlling the expand ability
             PostUserEvent(LINK(this, DBTreeListBox, OnResetEntry), pParent);
@@ -380,7 +351,7 @@ void DBTreeListBox::RequestHelp( const HelpEvent& rHEvt )
 void DBTreeListBox::KeyInput( const KeyEvent& rKEvt )
 {
     KeyFuncType eFunc = rKEvt.GetKeyCode().GetFunction();
-    USHORT		nCode = rKEvt.GetKeyCode().GetCode();
+    sal_uInt16		nCode = rKEvt.GetKeyCode().GetCode();
     sal_Bool bHandled = sal_False;
 
     if(eFunc != KEYFUNC_DONTKNOW)
@@ -434,20 +405,18 @@ void DBTreeListBox::KeyInput( const KeyEvent& rKEvt )
         // is used by the document will raise a similar bug once somebody discovers it.
         // If this is the case, we should discuss a real solution with the framework (SFX) and the
         // applications.
-        //
-        // 2002-12-02 - 105831 - fs@openoffice.org
     }
 
-    if ( !bHandled ) 
+    if ( !bHandled )
         SvTreeListBox::KeyInput(rKEvt);
 }
 // -----------------------------------------------------------------------------
-BOOL DBTreeListBox::EditingEntry( SvLBoxEntry* pEntry, Selection& /*_aSelection*/)
+sal_Bool DBTreeListBox::EditingEntry( SvLBoxEntry* pEntry, Selection& /*_aSelection*/)
 {
     return m_aEditingHandler.Call(pEntry) != 0;
 }
 // -----------------------------------------------------------------------------
-BOOL DBTreeListBox::EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText )
+sal_Bool DBTreeListBox::EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText )
 {
     DBTreeEditedEntry aEntry;
     aEntry.pEntry = pEntry;
@@ -458,12 +427,12 @@ BOOL DBTreeListBox::EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText
         m_aSelectedEntries.erase( pEntry );
     }
     SetEntryText(pEntry,aEntry.aNewText);
-    
-    return FALSE;  // we never want that the base change our text
+
+    return sal_False;  // we never want that the base change our text
 }
 
 // -----------------------------------------------------------------------------
-BOOL DBTreeListBox::DoubleClickHdl()
+sal_Bool DBTreeListBox::DoubleClickHdl()
 {
     long nResult = aDoubleClickHdl.Call( this );
     // continue default processing if the DoubleClickHandler didn't handle it
@@ -500,12 +469,12 @@ namespace
         if ( !_pPopup )
             return;
 
-        USHORT nCount = _pPopup->GetItemCount();
-        for (USHORT i=0; i < nCount; ++i)
+        sal_uInt16 nCount = _pPopup->GetItemCount();
+        for (sal_uInt16 i=0; i < nCount; ++i)
         {
             if ( _pPopup->GetItemType(i) != MENUITEM_SEPARATOR )
             {
-                USHORT nId = _pPopup->GetItemId(i);
+                sal_uInt16 nId = _pPopup->GetItemId(i);
                 PopupMenu* pSubPopUp = _pPopup->GetPopupMenu(nId);
                 if ( pSubPopUp )
                 {
@@ -532,23 +501,23 @@ namespace
 {
     void lcl_adjustMenuItemIDs( Menu& _rMenu, IController& _rCommandController )
     {
-        USHORT nCount = _rMenu.GetItemCount();
-        for ( USHORT pos = 0; pos < nCount; ++pos )
+        sal_uInt16 nCount = _rMenu.GetItemCount();
+        for ( sal_uInt16 pos = 0; pos < nCount; ++pos )
         {
             // do not adjust separators
             if ( _rMenu.GetItemType( pos ) == MENUITEM_SEPARATOR )
                 continue;
 
-            USHORT nId = _rMenu.GetItemId(pos);
+            sal_uInt16 nId = _rMenu.GetItemId(pos);
             String aCommand = _rMenu.GetItemCommand( nId );
             PopupMenu* pPopup = _rMenu.GetPopupMenu( nId );
             if ( pPopup )
             {
                 lcl_adjustMenuItemIDs( *pPopup, _rCommandController );
                 continue;
-            } // if ( pPopup )
+            }
 
-            const USHORT nCommandId = _rCommandController.registerCommandURL( aCommand );
+            const sal_uInt16 nCommandId = _rCommandController.registerCommandURL( aCommand );
             _rMenu.InsertItem( nCommandId, _rMenu.GetItemText( nId ), _rMenu.GetItemImage( nId ),
                 _rMenu.GetItemBits( nId ), pos );
 
@@ -564,30 +533,28 @@ namespace
     }
     void lcl_insertMenuItemImages( Menu& _rMenu, IController& _rCommandController )
     {
-        const StyleSettings& rSettings = Application::GetSettings().GetStyleSettings();
-        const BOOL bHiContrast = rSettings.GetHighContrastMode();
         uno::Reference< frame::XController > xController = _rCommandController.getXController();
         uno::Reference< frame::XFrame> xFrame;
         if ( xController.is() )
             xFrame = xController->getFrame();
-        USHORT nCount = _rMenu.GetItemCount();
-        for ( USHORT pos = 0; pos < nCount; ++pos )
+        sal_uInt16 nCount = _rMenu.GetItemCount();
+        for ( sal_uInt16 pos = 0; pos < nCount; ++pos )
         {
             // do not adjust separators
             if ( _rMenu.GetItemType( pos ) == MENUITEM_SEPARATOR )
                 continue;
 
-            USHORT nId = _rMenu.GetItemId(pos);
+            sal_uInt16 nId = _rMenu.GetItemId(pos);
             String aCommand = _rMenu.GetItemCommand( nId );
             PopupMenu* pPopup = _rMenu.GetPopupMenu( nId );
             if ( pPopup )
             {
                 lcl_insertMenuItemImages( *pPopup, _rCommandController );
                 continue;
-            } // if ( pPopup )
+            }
 
             if ( xFrame.is() )
-                _rMenu.SetItemImage(nId,framework::GetImageFromURL(xFrame,aCommand,FALSE,bHiContrast));
+                _rMenu.SetItemImage(nId,framework::GetImageFromURL(xFrame,aCommand,sal_False));
         }
     }
     // =========================================================================
@@ -623,24 +590,24 @@ namespace
         throw IllegalArgumentException();
         // API bug: this should be a NoSupportException
     }
-    
+
     //--------------------------------------------------------------------
     Any SAL_CALL SelectionSupplier::getSelection(  ) throw (RuntimeException)
     {
         return m_aSelection;
     }
-    
+
     //--------------------------------------------------------------------
     void SAL_CALL SelectionSupplier::addSelectionChangeListener( const Reference< XSelectionChangeListener >& /*_Listener*/ ) throw (RuntimeException)
     {
-        OSL_ENSURE( false, "SelectionSupplier::removeSelectionChangeListener: no support!" );
+        OSL_FAIL( "SelectionSupplier::removeSelectionChangeListener: no support!" );
         // API bug: this should be a NoSupportException
     }
-    
+
     //--------------------------------------------------------------------
     void SAL_CALL SelectionSupplier::removeSelectionChangeListener( const Reference< XSelectionChangeListener >& /*_Listener*/ ) throw (RuntimeException)
     {
-        OSL_ENSURE( false, "SelectionSupplier::removeSelectionChangeListener: no support!" );
+        OSL_FAIL( "SelectionSupplier::removeSelectionChangeListener: no support!" );
         // API bug: this should be a NoSupportException
     }
 }
@@ -700,7 +667,7 @@ PopupMenu* DBTreeListBox::CreateContextMenu( void )
                     break;
 
                 default:
-                    DBG_ERROR( "DBTreeListBox::CreateContextMenu: unexpected return value of the interceptor call!" );
+                    OSL_FAIL( "DBTreeListBox::CreateContextMenu: unexpected return value of the interceptor call!" );
 
                 case ContextMenuInterceptorAction_IGNORED:
                     break;
@@ -725,13 +692,13 @@ PopupMenu* DBTreeListBox::CreateContextMenu( void )
         // the interceptors only know command URLs, but our menus primarily work
         // with IDs -> we need to translate the commands to IDs
         lcl_adjustMenuItemIDs( *pModifiedMenu, m_pContextMenuProvider->getCommandController() );
-    } // if ( bModifiedMenu )
+    }
 
     return pContextMenu.release();
 }
 
 // -----------------------------------------------------------------------------
-void DBTreeListBox::ExcecuteContextMenuAction( USHORT _nSelectedPopupEntry )
+void DBTreeListBox::ExcecuteContextMenuAction( sal_uInt16 _nSelectedPopupEntry )
 {
     if ( m_pContextMenuProvider && _nSelectedPopupEntry )
         m_pContextMenuProvider->getCommandController().executeChecked( _nSelectedPopupEntry, Sequence< PropertyValue >() );
@@ -742,7 +709,7 @@ IMPL_LINK(DBTreeListBox, OnTimeOut, void*, /*EMPTY_ARG*/)
 {
     implStopSelectionTimer();
 
-    m_aSelChangeHdl.Call( NULL );	
+    m_aSelChangeHdl.Call( NULL );
     return 0L;
 }
 // -----------------------------------------------------------------------------
@@ -754,3 +721,5 @@ void DBTreeListBox::StateChanged( StateChangedType nStateChange )
 // .........................................................................
 }	// namespace dbaui
 // .........................................................................
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
