@@ -236,7 +236,7 @@ namespace dbaui
         {
             if ( _rData.m_xDocEventBroadcaster.is() )
             {
-                ::rtl::OUString sEventName( ::rtl::OUString::createFromAscii( _bActive ? "OnFocus" : "OnUnfocus" ) );
+                ::rtl::OUString sEventName = _bActive ? rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("OnFocus")) : rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("OnUnfocus"));
                 Reference< XController2 > xController( _rData.m_rController.getXController(), UNO_QUERY_THROW );
                 _rData.m_xDocEventBroadcaster->notifyDocumentEvent( sEventName, xController, Any() );
             }
@@ -295,11 +295,6 @@ namespace dbaui
                 const Window* pContainerWindow = VCLUnoHelper::GetWindow( xContainerWindow );
                 ENSURE_OR_THROW( pContainerWindow, "no Window implementation for the frame's container window!" );
 
-                /*const Window* pContainerParentWindow = pContainerWindow->GetParent();
-                if ( pContainerParentWindow && ( pContainerParentWindow->GetType() == WINDOW_BORDERWINDOW ) )
-                    pContainerParentWindow = pContainerParentWindow->GetParent();
-                m_pData->m_bIsTopLevelDocumentWindow = ( pContainerParentWindow == NULL );*/
-
                 m_pData->m_bIsTopLevelDocumentWindow = ( pContainerWindow->GetExtendedStyle() & WB_EXT_DOCUMENT ) != 0;
             }
 
